#
# spec file for package vulkan-loader
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libvulkan1
Name:           vulkan-loader
Version:        1.2.133
Release:        lp152.1.3
Summary:        Reference ICD loader for Vulkan
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/KhronosGroup/Vulkan-Loader
Source:         https://github.com/KhronosGroup/Vulkan-Loader/archive/v%version.tar.gz
Source9:        baselibs.conf
BuildRequires:  cmake >= 3.4
BuildRequires:  gcc-c++ >= 4.8
BuildRequires:  pkgconfig
BuildRequires:  python3-xml
BuildRequires:  vulkan-headers >= %version
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)

%description
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This package contains the reference ICD loader for Vulkan.

%package -n %lname
Summary:        The Vulkan 3D graphics and compute API
Group:          System/Libraries

%description -n %lname
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

%package -n vulkan-devel
Summary:        Vulkan development package
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release
Requires:       vulkan-headers >= %version

%description -n vulkan-devel
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This subpackage contains the development headers for packages wanting
to make use of Vulkan.

%prep
%autosetup -n Vulkan-Loader-%version

%build
%cmake \
	-DVulkanHeaders_INCLUDE_DIR:PATH="%_includedir" \
	-DVulkanRegistry_DIR:PATH="%_datadir/vulkan/registry"
%cmake_build

%install
%cmake_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n libvulkan1
%license LICENSE.txt
%_libdir/libvulkan.so.1*

%files -n vulkan-devel
%_libdir/libvulkan.so
%_libdir/pkgconfig/vulkan.pc

%changelog
* Tue Feb 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to release 1.2.133
  * Avoid clang warning about parentheses
  * secure_getenv change logging WARN to INFO
  * don't unconditionally add std-val meta layer
  * Fix buffer size updates in registry search
  * Add core 1.2 functions to gpa_helper
  * add null check to loaderValidateLayers
  * Warn when loader_secure_getenv() fails
  * Regenerate files for debug utils changes
  * Fix debug utils terminators being skipped
* Mon Feb  3 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to release 1.2.132
  * Improve 1.2 promoted extension fix
  * Fix handling of promoted device extensions
* Sun Jan 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.131
  * Support for Vulkan 1.2
* Mon Dec 23 2019 Martin Pluskal <mpluskal@suse.com>
- Use new macros (autosetup and cmake_build)
* Thu Dec 12 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.130
  * Support for vkGetPhysicalDeviceToolPropertiesEXT and other
    new extensions (cf. vulkan-docs).
* Thu Nov  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.127
  * Build system changes only
* Sat Oct 26 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.126
  * Build system changes only
* Wed Oct 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.124
  * loader: Add support for metal surfaces
  * loader: Use dxgi1_2 header instead of 1_6
  * loader: Dynamically load DXGI
  * layers: allow concurrent layer device creation
* Sun Sep 22 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to the new upstream release 1.1.123
  * loader: Match ICDs against DXGI adapters
* Wed Aug 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.120
  * loader: Make instance version report patch version
* Sun Aug 18 2019 Aaron Stern <ukbeast89@ptotonmail.com>
- Update to new upstream release 1.1.119
  * Additionally, ran `generate_source.py`.
* Fri Jun 28 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.112
  * loader: Fix bug in searching for missing extension
* Tue Jun  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.108
  * loader: VK_EXT_headless_surface additions
  * layers: add layer callbacks for device creation
* Sun Mar 24 2019 John Vandenberg <jayvdb@gmail.com>
- Use build dependency python-xml to fix Leap 42.3 builds
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.102
  * Build changes only, no user-visible points.
* Mon Feb 18 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.100
  * No changes, just a version bump to be in line
    with vulkan-headers.
* Thu Jan 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.97.0
  * loader: Fix memory not being zeroed after allocate
  * loader: Remove duplicate scanned json files
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.96
  * Documentation updates
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.95
  * docs: Use "ICD" instead of "layer" in ICD info
* Sun Dec  2 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.94
  * loader: Fix unwrapped loader instance being used
  * loader: Fix double free when enabling override
* Fri Nov 23 2018 Jan Engelhardt <jengelh@inai.de>
- Add back baselibs.conf that was in vulkan(.spec)
* Mon Nov 12 2018 Jan Engelhardt <jengelh@inai.de>
- Split vulkan SRPM -> vulkan-loader SRPM following a
  repository split upstream.
- Update to new snapshot 1.1.91
* Sat Aug 25 2018 jengelh@inai.de
- Update to new snapshot 1.1.73
  * layers: Removed obsolete (and duplicate) VUIDs
  * layers: Make unique_objects ID map global
  * layers: Add VUIDs for VK_KHR_incremental_present
  * layers: Add canonical/unique ID to pipeline layout
  * layers: Add support for StorageBuffer storage class
  * loader: Add new core 1.1 entry points
  * loader: Update loader for Vulkan 1.1
  * vulkaninfo: Add core 1.1 extensions
* Fri Mar  9 2018 crrodriguez@opensuse.org
- Skip building tests that are neither packaged nor ran.
* Fri Mar  9 2018 crrodriguez@opensuse.org
- vulkan-devel has missing dependencies, this causes further
  confusion down the dependency chain, fix it by adding
  the required X and wayland components
* Wed Mar  7 2018 jengelh@inai.de
- Update to new snapshot 1.1.70
  * Support for Vulkan 1.1 (Subgroup operations)
* Wed Feb  7 2018 jengelh@inai.de
- Update to new snapshot 1.0.68
  * layers: add image layout validation to vkCmdBlitImage()
  * layers: Add VK_EXT_validation_cache implementation for shaders
  * layers: Add layer metadata for EXT_validation_cache extension
  * layers: Add descriptor limit checks to vkCreatePipelineLayout()
  * layers: Create instance & device extension lists
- Add no-git.diff
* Wed Jan 10 2018 jengelh@inai.de
- Drop ImageMagick build-time requirement
* Thu Nov 16 2017 jengelh@inai.de
- Update to new snapshot 1.0.65
  * The VK_EXT_global_priority extension extends the concept of
    device-scope queue priorities to now be a system-wide scope.
    The global/system-wide priority level takes priority over the
    per-process queue priorities.
  * New extension VK_KHR_bind_memory2: This extension allows
    vkBindBufferMemory and vkBindImageMemory to support multiple
    bindings to be performed at once while also being more
    extensible.
  * New extension VK_KHR_image_format_list: Provides a list of
    all formats that can be used with a Vulkan image when it is
    created.
  * New extension VK_KHR_maintenance2: Adds in various changes
    that were left out of Vulkan previously. These maintenance
    updates allow implementations to express clipping behavior of
    points, creating images with usage flags that may not be
    supported for the base image's format, creating uncompressed
    image views of compressed images, two new image layouts for
    depth stencil images, and other minor changes.
  * New extension VK_KHR_sampler_ycbcr_conversion: Support to
    perform specified color space conversions during texture
    sampling operations.
- Drop 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
  (included upstream)
* Sat Aug 12 2017 jengelh@inai.de
- Update to new upstream release 1.0.57.0
  * loader: Do not enumerate extensions from disabled implicit
    layers
  * layers:Handle ALL_*_BIT pipe stage barrier validation
  * LVL: Add validation check for CreateImageView
  * loader: Remove executable stack from libvulkan.so
  * layers: Fix mismatched new[] / delete
  * layers: Add new PV ranged enum validation function
  * layers: Don't do bogus transitions in invalidateCommandBuffers
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 1.0.54
  * Fix a few potential overruns
  * Configurable fallback search paths
  * Validate device features: imageCubeArray, dualSrcBlend,
    multiDrawIndirect, depthClamp, depthBounds, alphaToOne,
    samplerAnisotropy.
  * Add compressed texture query utils
  * Add feature checks for textureCompressionETC2,
    textureCompressionASTC_LDR, textureCompressionBC,
    sparseBinding device, sparseResidencyBuffer,
    sparseResidencyAliased, depthBiasClamp.
  * Remove deprecated KHX extension from OT/PV
  * Support CapabilityGeometryShaderPassThroughNV and
    CapabilitySampleMaskOverrideCoverage.
  * Support the viewport_array2, shader_subgroup_ballot and
    shader_subgroup_vote ext shader caps.
  * Change size of X8_D24_UNORM_PACK32 and D32_SFLOAT_S8_UINT
- Add 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
* Mon Feb 20 2017 jengelh@inai.de
- Update to new upstream release 1.0.41
  * layers: Move image struct into cv_types header
  * layers: Move CreateImage validation into core_val
  * layers: Move DestroyImage code into buffer module
  * layers: Move CreateRenderPass format check to PV
  * layers: Rename misleading renderpass structure var
  * layers:Move gfx pipe check to create time
  * layers: Move image validation support to buffer_val
  * layers: Add enable for NV_GLSL_SHADER extension
- Add baselibs.conf [needed by libgtk-4-0]
* Mon Jan 30 2017 jengelh@inai.de
- Update to new upstream release 1.0.39.1
  * layers: Add tracking for VK_KHR_display extension in PV
  * layers: Add null checks to RetireWorkOnQueue
  * vulkaninfo: fix segfault when DISPLAY is not set
  * layers: Complete support for VK_KHR_Display ext
* Mon Oct 31 2016 jengelh@inai.de
- Update to 1.0.32.g28
  * vkjson: Rename VkJsonAllProperties to VkJsonDevice
  * loader: Fix json output of escape chars
  * loader: Fix segfault in vulkaninfo
  * Add vulkan C++ header
- Remove 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch
  (upstreamed).
* Mon Jun 13 2016 jengelh@inai.de
- Update to new snapshot 1.0.3.g5493
  * Added helpers: getSwapchainNode(), getSwapchainFromImage(),
  getImageNode(), getImageViewData(), getSamplerNode(),
  getBufferViewInfo(), getBufferNode().
- Resolve build failure stemming from new glslang version
- Add 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch.
  These were in a prior tarball made from a Fedora git,
  but we since switched to the upstream git.
* Wed Feb 17 2016 jengelh@inai.de
- Initial package (version 1.0.3.g19) for build.opensuse.org
